@@ -246,3 +246,7 @@ def main() -> None:
     except Exception as e:
         print(e, file=sys.stderr)
         sys.exit(1)
+
+
+if __name__ == "__main__":
+    main()
